pub enum PortalKind {
Nether,
End,
EndGateway,
}Expand description
Vanilla portal behavior kind tracked by an entity while it is inside a portal.
Java stores a reference to the Portal block behavior object. Steel keeps a
compact explicit kind here so entity state does not depend on block behavior
object identity.
Variants
Nether
Vanilla nether portal block.
End
Vanilla end portal block.
EndGateway
Vanilla end gateway block.
Implementations
Sourceimpl PortalKind
impl PortalKind
Sourcepub fn transition_time(self, world: &World, entity: &dyn Entity) -> i32
pub fn transition_time(self, world: &World, entity: &dyn Entity) -> i32
Returns vanilla Portal.getPortalTransitionTime.